import {
    Column,
    Entity,
    PrimaryGeneratedColumn,
    CreateDateColumn,
    BaseEntity,
    ManyToOne,
    ManyToMany,
    OneToMany
  } from 'typeorm';
  import {User} from './User';
  import {Task} from './Task';


  interface IProject{
    id: string;
    title: string;
    color: string;
    admin:User;
    workers:User[];
    tasks:Task[]|null;
    createdAt: Date;
    dateDue: Date| null;
    department:boolean| false;
  }

  @Entity({ name: 'Project' })
  export class Project extends BaseEntity implements IProject{
    @PrimaryGeneratedColumn('uuid')
    id!: string
    @Column({ name: 'title', type: 'varchar', length:100,nullable: false })
    title!: string

    @CreateDateColumn({ name: 'createdAt', type: Date, default: new Date() })
    createdAt!: Date;

    @Column({ name: 'color', type: 'varchar', length:100,nullable: false })
    color!: string

    @Column({ name: 'dateDue', type: Date, default: null })
    dateDue!: Date| null;

    @Column({ name: 'department', type: Boolean, default: false })
    department!: boolean| false;

    @ManyToOne(() => User, (user: { projects: Project[]; }) => user.projects)
    admin!: User;

    @ManyToMany(() => User, (user: { projects: Project[]; }) => user.projects)
    workers!: User[];

    @OneToMany(() => Task, (task: { project: Project; })=>task.project)
    tasks!:Task[]|null;
  }
