import {
    Column,
    Entity,
    PrimaryGeneratedColumn,
    CreateDateColumn,
    BaseEntity,
    ManyToOne,
    ManyToMany
  } from 'typeorm';
  import {User} from './User';
  import {Project} from './Project';

  type taskFinishType = "open" | "done" |"failed";

  interface ITask{
    id: string;
    title: string;
    // description: string;
    createdAt: Date| undefined;
    // dateTimeStart:Date| null;
    // dateTimeDue:Date| null;
    assignedTo: User[];
    accomplish: taskFinishType;
    author: User;
    project:Project|null;
  }

  @Entity({ name: 'Task' })
  export class Task extends BaseEntity implements ITask{
    @PrimaryGeneratedColumn('uuid')
    id!: string
    @Column({ name: 'title', type: 'varchar', length:50,nullable: false })
    title!: string
    // @Column({ name: 'description', type: 'varchar', length:50,nullable: false })
    // description!: string
    @CreateDateColumn({ name: 'created_at', type: Date, default: new Date() })
    createdAt: Date | undefined;
    // @CreateDateColumn({ name: 'dateTimeStart', type: Date,nullable: true })
    // dateTimeStart!: Date | null;
    // @CreateDateColumn({ name: 'dateTimeDue', type: Date,nullable: true })
    // dateTimeDue!: Date | null;
    @Column({
        type: "enum",
        enum: ["opened", "done" , "failed"],
        default: "opened"
      })
      accomplish!: taskFinishType


    @ManyToOne(() => User, (user: { tasks: Task[]; }) => user.tasks)
      author!: User;

    @ManyToMany(() => User, (user: { tasks: Task[]; }) => user.tasks)
      assignedTo!: User[];

    @ManyToOne(()=>Project,(task: {project:Project}) => task.project)
    project!: Project | null;
  }
